<?php
/*
Plugin Name: Event-O-Matic
Plugin URI: http://garvinmedia.com/eom
Description: The Awesome Event Submission and Management Engine. Manage submissions to build a community-driven event listing. Allow users to submit events that you can easily review and moderate. Add lists of upcoming and past events and venues around your community. Integrated with Google Maps for simple address verification. 
Version: 2.4.1
Author: Matthew Garvin
Author URI: http://garvinmedia.com

CONVENTIONS
-Methods, properties are camelCased to distinguish from wp functions
-Admin included within eom_admin.php and class extends Event_O_Matic
-User, Event, Venue, and Date classes built for better code seperation

THANK YOU
-Character Count copyright 2007 Tom Deater (http://www.tomdeater.com)
-Datepicker copyright 2008 Kelvin Luck (http://www.kelvinluck.com/)
-Validator copyright 2006 Jörn Zaefferer (http://docs.jquery.com/Plugins/Validation)

The problem with designing a system that's absolutely foolproof is that one invariably underestimates the ingenuity of absolute fools
*/

/*****************
Define some tables
*****************/
global $wpdb;
define("EOMEVENTS", $wpdb->prefix."eom_events");
define("EOMVENUES", $wpdb->prefix."eom_venues");
define("EOMUSERS", $wpdb->prefix."eom_users");
define("EOMDATES", $wpdb->prefix."eom_dates");


/*****************
CLASS Event_O_Matic
*****************/
if(!class_exists("Event_O_Matic")) {class Event_O_Matic{

//configuration options
protected $error=array();
protected $notification=array();
protected $errorMsg=array(
	'event' =>'Please check event information and resubmit.', 
	'eventSave'=>'Error saving event. Please try again',
	'userEmail'=>'Please check you have submitted your email correctly and try again.', 
	'user'=>'Please check your name and email and resubmit.',
	'venueSave'=>'Error saving venue. Please try again.',
	'venueData'=>'Invalid Venue. Check address and resubmit.',
	'venue'=>'Please select a venue from the list or add a venue name and address.');
protected $notificationMsg=array(
	'venueUpdate'=>'Venue updated.',
	'venueInsert'=>'Venue created.',
	'venueDelete'=>'Venue deleted.',
	'eventInsert'=>'Event created.',
	'eventUpdate'=>'Event updated.',
	'eventDelete'=>'Event deleted.',
	'eventPending'=>'Pending events need approval.');
protected $status=array('approved'=>'A','pending'=>'P');
protected $config=array('descriptionMax'=>1000);
protected $datefield=array('start'=>'dateStart','end'=>'dateEnd');

//constructor
public function __construct(){
	include_once('user.php');
	include_once('venue.php');
	include_once('event.php');
	include_once('date.php');
	include_once('pagination.class.php');
}

//install
public function install(){
	global $wpdb;
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	//add db version
	add_option("eom_db_version", '0.3');
	
	
	if($wpdb->get_var("SHOW TABLES LIKE '".EOMEVENTS."'") != EOMEVENTS){
		$sql = "CREATE TABLE ".EOMEVENTS." (
		id int(10) NOT NULL AUTO_INCREMENT,
		venue_id int(10) DEFAULT '0' NOT NULL,
		user_id int(10) DEFAULT '0' NOT NULL,
		name VARCHAR(150) NOT NULL,
		timestamp TIMESTAMP NOT NULL,
		type CHAR(1) NOT NULL,
		status CHAR(1) NOT NULL,
		description TEXT NOT NULL,
		price DECIMAL(5,2) NOT NULL,
		flyer VARCHAR(200) NOT NULL,
		website VARCHAR(200) NOT NULL,
		UNIQUE KEY id (id)
		);";
		dbDelta($sql);
	}
	if($wpdb->get_var("SHOW TABLES LIKE '".EOMDATES."'") != EOMDATES){
		$sql = "CREATE TABLE ".EOMDATES." (
		id int(10) NOT NULL AUTO_INCREMENT,
		event_id int(10) DEFAULT '0' NOT NULL,
		timestamp TIMESTAMP NOT NULL,
		start DATETIME NOT NULL,
		end DATETIME NOT NULL,
		UNIQUE KEY id (id)
		);";
		dbDelta($sql);
	}
	//add state to venue
	if($wpdb->get_var("SHOW TABLES LIKE '".EOMVENUES."'") != EOMVENUES){
		$sql = "CREATE TABLE ".EOMVENUES." (
		id int(10) NOT NULL AUTO_INCREMENT,
		timestamp TIMESTAMP NOT NULL,
		name VARCHAR(100) NOT NULL,
		street VARCHAR(100) NOT NULL,
		city VARCHAR(75) NOT NULL,
		status CHAR(1) NOT NULL,
		fullAddress VARCHAR(200) NOT NULL,
		lat DECIMAL(12,7) NOT NULL, 
		lon DECIMAL(12,7) NOT NULL,
		UNIQUE KEY id (id)
		);";
		dbDelta($sql);
	}	
	if($wpdb->get_var("SHOW TABLES LIKE '".EOMUSERS."'") != EOMUSERS){
		$sql = "CREATE TABLE ".EOMUSERS." (
		id int(10) NOT NULL AUTO_INCREMENT,
		timestamp TIMESTAMP NOT NULL,
		name VARCHAR(75) NOT NULL,
		email VARCHAR(75) NOT NULL,
		UNIQUE KEY id (id)
		);";
		dbDelta($sql);
	}
}

//method to create eom submission form - USE SHORTCODE [eom-public-form]
public function eomForm(){

//create venue, event, date, user objects
$venue = new Venue();
$event = new Event();
$date = new Date();
$user = new User();

/***start form, check email***/
if($_REQUEST['_submitEmail']){
	//get user from database
	if(!$user->get($_REQUEST['userEmail'])){
		//if no user in db, put user into object
		$user->put(array('email'=>$_REQUEST['userEmail']));
	}
	//email error, back to email form or direct to eventSubmit
	if(!$user->email){$this->error[]=$this->errorMsg['userEmail'];}
	else{$locationFlag='eventSubmit';}
}
	
/***check event data, route to confirm, edit, commit based on button***/
if($_REQUEST['_submitEvent'] || $_REQUEST['_submitEventEdit'] || $_REQUEST['_submitEventCommit']){
	$userTest=$user->put(array('email'=>$_REQUEST['userEmail'],'name'=>$_REQUEST['userName']));
	$venue->put(array(
		'id'=>$_REQUEST['venueId'],
		'name'=>$_REQUEST['venueName'],
		'address'=>$_REQUEST['venueAddress']
	));
	$event->put(array(
		'name'=> $_REQUEST['eventName'],
		'description'=> $_REQUEST['eventDescription'],
		'price'=> $_REQUEST['eventPrice'],
		'image'=> $_REQUEST['eventImage'],
		'url'=> $_REQUEST['eventUrl'],
		'status'=> $event->statusCode['pending'] 
	));
	$date->put(array(
		'start'=>$_REQUEST['dateStart'],
		'startTime'=>$_REQUEST['dateStartTime'],
		'end'=> $_REQUEST['dateEnd'],
		'endTime' => $_REQUEST['dateEndTime'] 
	));
	//check all data
	if(!$userTest){$this->error[]=$this->errorMsg['user'];}
	if(!$event->name || !$event->description){$this->error[]=$this->errorMsg['event'];}
	if(!$venue->name || !$venue->address){
		if($venue->id){$venue->getById();}else{$this->error[]=$this->errorMsg['venue'];}
	}
	//tabulate errors and report
	$this->error=array_merge($this->error,$date->error,$venue->error);
	
	//routing, no errors
	if( count($this->error)==0 ){
		if($_REQUEST['_submitEventCommit']){
			//add to db
			$user->save();
			//if venue data, insert
			if(!$venue->id){$venue->save();}
			//now that you have $user->id and $venue->id, add event
			$event->userId=$user->id;
			$event->venueId=$venue->id;
			$event->status=$this->status['pending'];
			$event->save();
			//add date
			$date->eventId=$event->id;
			$date->save();
			//success, email admin
			$headers = 'From: '.get_bloginfo('name').' <'.get_bloginfo('admin_email').'>' . "\r\n\\";
$message="Greetings, 
	a new event has been submitted to the Event-O-Matic. ".stripslashes($event->name)." - ".stripslashes($event->description)." Go check it out.";
			wp_mail( get_bloginfo('admin_email'), get_bloginfo('name').' - New Event Submitted', $message, $headers);
			$locationFlag='eventSuccess';
		}
		elseif($_REQUEST['_submitEvent']){$locationFlag='eventConfirm';}
		else{$locationFlag='eventSubmit';}
	}else{ //routing, error - return to form
		$locationFlag='eventSubmit';
	}
}// END ata checking

//FORM
$r = $this->_formatMessages().'<form id="eom" method="post" action="'.$_SERVER['REQUEST_URI'].'" >';
$r.= wp_nonce_field('eomNonce');

switch ($locationFlag):
case 'eventSubmit':
	$r.='<em><a href="'.$_SERVER['REQUEST_URI'].'">Start over</a></em>';
	if($user->returning):
		$r.='<p>Welcome back, '.$user->name.'</p>';
		$r.='<input type="hidden" name="userName" value="'.htmlspecialchars($user->name).'" />';
	else:
		$r.='<p align="left">Your Email:<br />';
		$r.='<input type="text" size="40" maxlength="75" value="'.$user->email.'" disabled="disabled" />';
		$r.='<p align="left"><label for="userName">Your Name:</label><br />';
		$r.='<input type="text" name="userName" class="required" size="40" maxlength="75" value="'.$user->name.'" />';
	endif;
	$r.='<input type="hidden" name="userEmail" value="'.$user->email.'" />';
	$r.='<p align="left"><label for="eventName">Event Name:</label><br />';
	$r.='<input type="text" name="eventName" class="required" size="40" maxlength="75" value="'.htmlspecialchars($event->name).'" />';
	$r.='<p align="left"><label for="eventDescription">Event Description:</label><br />';
	$r.='<textarea name="eventDescription" id="eventDescription" class="required" cols="50" rows="5">'.$event->description.'</textarea>';
	$r.='<p align="left">Start Time:<br />'.$this->_fieldDate($this->datefield['start'],$date->start).'</p>';
	$r.='<p align="left">End Time:<br />'.$this->_fieldDate($this->datefield['end'],$date->end).'</p>'; 
	$r.='<table><tr><td valign="top"><p align="left">Venue:<br />'.$venue->fieldVenue($venue->id).'</p>';
	$r.='</td><td valign="middle">-OR-</td><td valign="top"><p>Add A New Venue:</p>';
	$r.='<p align="left"><label for="venueName">Venue Name:</label><br />';
	if(!$venue->id){$vres=$venue->name;$vadd=$venue->address;}else{$vres='';$vadd='';}
	$r.='<input type="text" name="venueName" size="40" maxlength="100" value="'.$vres.'" /></p>';
	$r.='<p align="left"><label for="venueAddress">Venue Address:</label><br />';
	$r.='<input type="text" name="venueAddress" size="40" maxlength="200" value="'.$vadd.'" /></p></td></tr></table>';
	$r.='<p align="left"><label for="eventUrl">Website (optional):</label><br />';
	$r.='<input type="text" name="eventUrl" class="url" size="40" maxlength="100" value="'.$event->url.'" /></p>';
	$r.='<p align="left"><label for="eventImage">Image URL (optional):</label><br />';
	$r.='<input type="text" name="eventImage" class="url" size="40" maxlength="100" value="'.$event->image.'" /></p>';
	$r.='<p align="left"><label for="eventPrice">Price (optional):</label><br />';
	$r.='<input type="text" name="eventPrice" class="number" size="10" maxlength="10" value="'.$event->price.'" /></p>';
	$r.='<p><input type="submit" name="_submitEvent" value="Submit Event" /></p>';
break; //END eventSubmit

case 'eventConfirm':
	$r.='<h2>Confirm Information</h2>';
	$r.='<p>'.$user->name.' confirm the information below is correct and submit your event for approval.</p>';
	$r.='<br class="clear" />';
	if($event->image){$r.='<img src="'.esc_url($event->image).'" class="alignright" width="200" />';}
	$r.='<h3>'.$event->name.'</h3>';
	$r.='<p>'.date('F jS \a\t g:ia',strtotime($date->start)).' to '.date('F jS \a\t g:ia',strtotime($date->end)).'</p>';
	$r.='<p><em>'.nl2br($event->description).'</em></p>';
	if($event->price){$r.='<p>Price: '.$event->price.'</p>';}
	if($event->url){$r.='<p><a href="'.esc_url($event->url).'">'.esc_url($event->url).'</a></p>';}
	$r.='<h3>'.$venue->name.'</h3>';
	$r.='<p>'.$venue->address.'</p><br class="clear" />';
	$r.='<input type="hidden" name="userEmail" value="'.htmlspecialchars($user->email).'" />';
	$r.='<input type="hidden" name="userName" value="'.htmlspecialchars($user->name).'" />';
	$r.='<input type="hidden" name="eventName" value="'.htmlspecialchars($event->name).'" />';
	$r.='<input type="hidden" name="eventDescription" value="'.htmlentities($event->description).'" />';
	$r.='<input type="hidden" name="dateStart" value="'.$date->start.'" />';
	$r.='<input type="hidden" name="dateEnd" value="'.$date->end.'" />';
	if($venue->id):
		$r.='<input type="hidden" name="venueId" value="'.$venue->id.'" />';
	else:
		$r.='<input type="hidden" name="venueName" value="'.htmlspecialchars($venue->name).'" />';
		$r.='<input type="hidden" name="venueAddress" value="'.htmlspecialchars($venue->address).'" />';
	endif;
	$r.='<input type="hidden" name="eventUrl" value="'.$event->url.'" />';
	$r.='<input type="hidden" name="eventImage" value="'.$event->image.'" />';
	$r.='<input type="hidden" name="eventPrice" value="'.$event->price.'" />';
	$r.='<input type="submit" name="_submitEventEdit" value="Edit Event" />';
	$r.='<input type="submit" name="_submitEventCommit" value="Confirm Event" />';
break; //END eventConfirm

case 'eventSuccess':
	$r.='<h2>Thank You</h2><p>Your event has been submitted for review.</p>';
	$r.='<p><a href="'.get_bloginfo('url').'"> Return to '.get_bloginfo('name').'</a></p><br class="clear" />';
break; //END eventSuccess

default:
	$r.='<p>Enter your email address and click submit to begin.</p>';
	$r.='<p align="left"><label for="userEmail">Your Email:</label><br />';
	$r.='<input type="text" name="userEmail" class="required email" size="40" maxlength="75" />';
	$r.='<br /><input type="submit" name="_submitEmail" value="Submit" /></p>';
endswitch;

$r.='</form>'.$this->_linkLove();
return $r;
}//END eomForm


// venue listings - USE SHORTCODE [eom-venues]
public function eomVenues(){
	$venue = new Venue;
	if($_GET['vid']){
		$venue->put(array('id'=>$_GET['vid']));
		$venue->getById();
		return '<h1>'.stripslashes($venue->name).'</h1><p>'.stripslashes($venue->address).'</p><div id="eomMap"></div>';
	}else{ //default
	$p = new pagination;
	$venueCount=$venue->getAll(array('count'=>true));
	$p->items($venueCount); //get all records as count
	$p->limit(30); // Limit entries per page
	$p->currentPage($_GET[$p->paging]); // Gets and validates the current page
	$p->calculate(); // Calculates what to show
	$p->parameterName('paging');
	if(!isset($_GET['paging'])) {$p->page=1;}else{$p->page=$_GET['paging'];}
	$limit = ($p->page - 1) * $p->limit.", ".$p->limit; //Query for limit paging
	$venues=$venue->getAll(array('limit'=>$limit,'order'=>'name'));
	if($venueCount>0):
		$r='<p>'.$venueCount.' venues.</p>';
		$r.='<div class="tablenav"><div class="tablenav-pages">'.$p->getOutput().'</div></div><ul>';
		foreach($venues as $venue){
			$r.='<li><a href="'.add_query_arg('vid', $venue['id']).'">'.stripslashes($venue['name']).'</a></li>';
		}
		$r.='</ul><div class="tablenav"><div class="tablenav-pages">'.$p->getOutput().'</div></div>'.$this->_linkLove();
		return $r;
	else:
		return '<p>No venues available.</p>';
	endif;	
	}
}//END eomVenues


// eom listings. USE SHORTCODE [eom-listings] or [eom-listings when=archive]
public function eomListings($atts){
	extract(shortcode_atts(array('when' => 'upcoming'), $atts));
	if($when=='archive'){$when='archive';$direc='DESC';}else{$when='upcoming';$direc='ASC';}
	$event = new Event;
	if($_REQUEST['id']){
		$event->put(array('id'=>$_REQUEST['id']));
		$event->get(array('status'=>$event->statusCode['approved']));
		$r = '<h1>'.stripslashes($event->name).'</h1>';
		$r.= '<h2>'.date("F jS Y g:ia",strtotime($event->dateStart)).' - '.date("g:ia",strtotime($event->dateEnd)).' at <a href="#eomAddress">'.stripslashes($event->venueName).'</a></h2>';
		if($event->price!=0.00){$r.='<p>Price: '.$event->price.'</p>';}
		$r.= nl2br($event->description).'</p>';
		if($event->url || $when=='upcoming'){$r.='<p>More details: <a href="'.clean_url($event->url).'" target="_blank" />'.clean_url($event->url).'</a></p>';}
		if($event->image){$r.='<img src="'.clean_url($event->image).'" class="eomImage" />';}
		$r.='<br style="clear:both;"><a name="eomAddress"></a>';
		$r.= '<p><strong>'.stripslashes($event->venueName).'</strong><br />'.$event->venueAddress.'</p>';
		$r.= '<div id="eomMap"></div>';
		return $r;
	}else{ //default
	$p = new pagination;
	$eventsCount=$event->getAll(array('status'=>$event->statusCode['approved'],'count'=>true,'when'=>$when));
	$p->items($eventsCount); //get all records as count
	$p->limit(30); // Limit entries per page
	$p->currentPage($_GET[$p->paging]); // Gets and validates the current page
	$p->calculate(); // Calculates what to show
	$p->parameterName('paging');
	if(!isset($_GET['paging'])) {$p->page=1;}else{$p->page=$_GET['paging'];}
	$limit = ($p->page - 1) * $p->limit.", ".$p->limit; //Query for limit paging
	$events=$event->getAll(array('status'=>$event->statusCode['approved'],'limit'=>$limit,'when'=>$when,'order'=>'dateStart','orderDirection'=>$direc));
	if($eventsCount>0):
		$r='<p>'.$eventsCount.' '.$when.' events.</p>';
		$r.='<div class="tablenav"><div class="tablenav-pages">'.$p->getOutput().'</div></div><ul>';
		foreach($events as $event){
			$r.='<li><a href="'.add_query_arg(array('id'=>$event['id'],'vid'=>$event['venueId'])).'">'.stripslashes($event['name']).'</a> - '.date("F jS Y",strtotime($event['dateStart'])).' - '.stripslashes($event['venueName']).'</li>';
		}
	$r.='</ul><div class="tablenav"><div class="tablenav-pages">'.$p->getOutput().'</div></div>'.$this->_linkLove();
	return $r;
	else:
		return '<p>No events available.</p>';
	endif;	
}
	
}//END eomListings


//call javascript libraries
public function jsLibraries(){
	wp_enqueue_script('validate', plugin_dir_url( __FILE__ ).'js/jquery.validate.min.js',array('jquery'));  
	wp_enqueue_script('count', plugin_dir_url( __FILE__ ).'js/charactercount.js');
	wp_enqueue_script('datemethods', plugin_dir_url( __FILE__ ).'js/date.js', array('jquery'));
	wp_enqueue_script('datepicker', plugin_dir_url( __FILE__ ).'js/jquery.datepicker.js',array('jquery'));
	wp_enqueue_script('jqueryui', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.9/jquery-ui.min.js');
	wp_enqueue_script('googleMap', 'http://maps.google.com/maps/api/js?sensor=false',array('jquery'));
	wp_enqueue_script('gmaps', plugin_dir_url( __FILE__ ).'js/jquery.ui.map.min.js',array('jquery'));
}

//call css libraries
public function cssLibraries(){
	wp_enqueue_style('eom',plugin_dir_url( __FILE__ ).'css/event-o-matic.css');
	wp_enqueue_style('datepicker',plugin_dir_url( __FILE__ ).'css/datepicker.css');
}

//call head content
public function eomHead(){?>
	<!--Event-O-Matic-->
	<script type="text/javascript" charset="utf-8">
	jQuery(document).ready(function($){
		$("#eventDescription").charCounter(<?=$this->config['descriptionMax'];?>);
		$("#eom").validate();
		Date.firstDayOfWeek = 0;
		Date.format = 'mm/dd/yyyy';
		$('.date-pick').datePicker({clickInput:true,createButton:false});
	<?php if(is_admin()): //allow past date selection for admin ?>
		$('.date-pick').datePicker({startDate:'01/01/2010'});
	<?php else: ?>
	$('#<?=$this->datefield['start'];?>').bind(
		'dpClosed',
		function(e, selectedDates){var d = selectedDates[0];
			if (d) {d = new Date(d);
			$('#<?=$this->datefield['end'];?>').dpSetStartDate(d.addDays(0).asString());}}
	);
	$('#<?=$this->datefield['end'];?>').bind(
		'dpClosed',
		function(e, selectedDates){var d = selectedDates[0];
			if (d) {d = new Date(d);
			$('#<?=$this->datefield['start'];?>').dpSetEndDate(d.addDays(-1).asString());}}
	);
	<?php endif;
	//display google map
	if($_GET['vid']){$venueId=(int)$_GET['vid'];}
	elseif($_GET['location']=='venue'){$venueId= (int) $_GET['id'];}
	$venue = new Venue;$venue->put(array('id'=>$venueId));$venue->getById();
	if($venue->address):?>
	var latlng = new google.maps.LatLng(<?php echo $venue->lat;?>, <?php echo $venue->lon;?>);
	$('#eomMap').gmap({
			'center': latlng, 
			'zoom' : 14,
			'callback': function(){
				$('#eomMap').gmap('addMarker', {'position': latlng, 'title': '<?php echo $venue->name;?>'});
			}
    });
	<?php endif; ?>
});</script><!--END Event-O-Matic--><?php
}


/*****************
PRIVATE METHODS
*****************/
//return errors and notifications within respective arrays, formatted in styled <div>
protected function _formatMessages(){
	$message='';
	if(is_admin()){
		if( !empty($this->error) || !empty($this->notification)){
			$message.='<div id="message" class="updated fade">';
			if(!empty($this->error)){foreach($this->error as $val){$message.='<p>'.$val.'</p>';}}
			if(!empty($this->notification)){foreach($this->notification as $val){$message.='<p>'.$val.'</p>';}}
			$message.='</div>';}
	}else{
		if(!empty($this->notification)){
		$message.='<div class="eomNotification">';
		foreach($this->notification as $val){$message.='<li>'.$val.'</li>';}
		$message.='</div>';}
		if(!empty($this->error)){
		$message.='<div class="eomError">';
		foreach($this->error as $val){$message.='<li>'.$val.'</li>';}
		$message.='</div>';}
	}
	return $message;
}

protected function _fieldDate($name, $date=''){
	//2011-01-17 13:00:00
	if($date){
		$d=explode(' ', $date);
		$date=explode('-',$d[0]);
		$date=$date[1].'/'.$date[2].'/'.$date[0];
		$time=$d[1];
	}else{$date=date("n/j/Y");}
	if($date!=''){
		$d=date_parse($date);
		if($d){$dateSel=$d['month'].'/'.$d['day'].'/'.$d['year'];}
	}else{$dateSel=date("n/j/Y");}
	//fill with date data, or submit today's date
	$form.='<input name="'.$name.'" id="'.$name.'" readonly="readonly" class="date-pick required date" value="'.$dateSel.'" />';
	$form.=' at <select name="'.$name.'Time">';
	for ($i = 0; $i < 24; $i++){
		$osel='';
		$hsel='';
		$time = date('G:i',strtotime($time));
		if(($i.':00')==$time){$osel='selected="selected"';}
		if(($i.':30')==$time){$hsel='selected="selected"';}
		$j=$i;
		if($i==0){$j=12;$ap='am';}
		if($i>12){$j=$j-12;$ap='pm';}
		if($i==12){$ap='pm';}
		$form.='<option value="'.$i.':00" '.$osel.'>'.$j.':00 '.$ap.' </option>';
		$form.='<option value="'.$i.':30" '.$hsel.'>'.$j.':30 '.$ap.' </option>';
	}
	$form.='</select>';
	return $form;
}

protected function _linkLove(){
	if(get_option('eom_link_love')!='no'){
		return '<a  style="font-size:9px;" href="http://garvinmedia.com/eom?love='.get_bloginfo('url').'" target="_blank">Powered by Event-O-Matic</a>';}
}

}}//End Class Event_O_Matic

//CREATE OBJECT
if (class_exists("Event_O_Matic")) {$eomObject = new Event_O_Matic();}

/*****************
HOOKS, SHORTCODE, INSTALL
*****************/
if ( isset($eomObject)  ) {
	add_shortcode("eom-venues", array($eomObject, 'eomVenues'));
	add_shortcode("eom-listings", array($eomObject, 'eomListings'));
	add_shortcode("eom-public-form", array($eomObject, 'eomForm'));
	add_action('wp_print_scripts', array($eomObject, 'jsLibraries'));
	add_action('wp_print_styles', array($eomObject, 'cssLibraries'));
	add_action('wp_head', array($eomObject, 'eomHead'));
	register_activation_hook(__FILE__,array($eomObject, 'install'));
}

/*****************
WIDGET & ADMIN
*****************/
include('widget.php');
if (is_admin()){include('eom_admin.php');}

?>