<?php

class Venue{

//private $apiKey;
private $table;
//private $debug = true;

public $id;
public $name;
public $address;
public $street;
public $city;
public $state;
public $country;
public $lat;
public $lon;
public $error = array();

function __construct(){
	global $wpdb;
	$this->table = $wpdb->prefix."eom_venues";
	//$this->apiKey = get_option('eom_google_api');
	//get rid of google api - not needed anymore!
	delete_option("eom_google_api");
}

//put venue name and address into object. checks validity of address with google and existence in db
public function put($data){
	$this->id = $this->_validate($data['id'], true, 1, 10, 'number');
	$this->name = $this->_validate($data['name'], true, 1, 100, 'text');
	$address = $this->_validate($data['address'], true, 1, 200, 'text');
	if($address){
		$place = $this->lookup($address);
		if(is_array($place)){
			
			//array of results returned
			if(count($place)==1){
				
				$existsResult = $this->exists($place[0]['formatted_address']);
				if(($existsResult)  && ($existsResult != $this->id)){
					//does address exist AND does it not equal this venue id
					$this->error[]='A venue with this address already exists.';return false;
				}
				if($place[0]['components']['route']){
					$this->street = $place[0]['components']['street_number'].' '.$place[0]['components']['route'];
				}
				//locality or sublocality for city
				if($place[0]['components']['locality']){
					$this->city = $place[0]['components']['locality'];
				}else{$this->city = $place[0]['components']['sublocality'];}
				//$this->state = $place[0]['components']['administrative_area_level_1'];
				//$this->country = $place[0]['components']['country'];
				if($place[0]['formatted_address']){$this->address = $place[0]['formatted_address'];}
				if($place[0]['coordinates']['lat'] && $place[0]['coordinates']['lon']){
					$this->lat = $place[0]['coordinates']['lat'];
					$this->lon = $place[0]['coordinates']['lon'];
				}
				//confirm all of these items have been added, or error
				if($this->street && $this->city && $this->address && $this->lat && $this->lon){
					//something done here?
				}else{
					$this->error[]='An address could not be resolved with the information entered. Please add a more specific address.';return false;
				}
			}else{
				$this->error[]='Multiple results exist for the address information you have entered. Please add a more specific address.';return false;
			}
		}else{
			//not an array, status error returned
			$this->error[]='Error encountered during lookup. '.$place;return false;
		}
	}
}

//ta-da! new lookup function return array of results, or error code on failure
function lookup($search){
	$url = sprintf('http://maps.googleapis.com/maps/api/geocode/json?address=%s&sensor=false', urlencode($search));
	$ch = curl_init($url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$response = curl_exec($ch);
	curl_close($ch);
	$response = json_decode( $response );
	//check response code
	switch ($response->status) {
		case 'OK': //response is good, parse responses
			foreach ($response->results as $key => $result){
				//full postal address
				$address_to_return[$key]['formatted_address'] = $result->formatted_address;
				//geocoding coordinates
				$address_to_return[$key]['coordinates'] = array(
					'lat'=>$result->geometry->location->lat ,
					'lon'=>$result->geometry->location->lng
				);
				//address components
				foreach ($result->address_components as $val){
					//big kludge here - we assume the correct tag will be indexed at [0]
					$address_array[$val->types[0]] = $val->short_name;
				}
				$address_to_return[$key]['components'] = $address_array;
			}
			//debug($response->results); //all results
			//debug($address_to_return); //just what we've parsed out
			return $address_to_return;
		break;
		case 'ZERO_RESULTS':
			return 'Zero results found.';
		break;
		case 'OVER_QUERY_LIMIT':
			return 'Over daily lookup quota.';
		break;
		case 'REQUEST_DENIED';
			return 'Request denied.';
		break;
		case 'INVALID_REQUEST';
			return 'Bad request.';
		break;
	}
}

//add to database. Return 2 if update, 1 if insert, false on fail
public function save(){
	global $wpdb;
	$data=array('name'=>$this->name, 'street'=>$this->street,'city'=>$this->city, 'fullAddress'=>$this->address, 'lat'=>$this->lat, 'lon'=>$this->lon);
	$datatype=array( '%s','%s','%s','%s','%F','%F' );
	if($this->id){
		//update
		$wpdb->update( $this->table, $data, array('id'=>$this->id), $datatype, '%d');
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 2;
	}else{
		//insert
		$wpdb->insert($this->table, $data, $datatype);
		$this->id = (int) $wpdb->insert_id;
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 1;
	}
	return false;
}


public function getAll($var=array('limit'=>NULL,'count'=>NULL,'order'=>NULL)){
	global $wpdb;
	if($var['order']){$orderSQL='ORDER BY '.$var['order'];}else{$orderSQL='';}
	if($var['limit']){$limitSQL=" LIMIT ".$var['limit']." ";}else{$limitSQL='';}
	if($var['count']){$select="COUNT(*)";}else{$select="*";}
	$sql=$wpdb->prepare("SELECT ".$select." FROM ".$this->table." ".$orderSQL." ".$limitSQL);
	//if count, use get_var
	if($var['count']){$results=$wpdb->get_var($sql);}else{
		$results=$wpdb->get_results($sql, ARRAY_A);
	}
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	return $results;
}

//populate object based on address
public function get($address){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT * FROM ".$this->table." WHERE fullAddress = %s", $address);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		$this->id = (int) $venue['id'];
		$this->name = $venue['name'];
		$this->address = $venue['fullAddress'];
	}else{return false;}
}

//populate object based on id
public function getById(){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT * FROM ".$this->table." WHERE id = %d;",$this->id);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		$this->name = $venue['name'];
		$this->address = $venue['fullAddress'];
		$this->lat = $venue['lat'];
		$this->lon = $venue['lon'];
		return true;
	}else{return false;}
}

//delete venue
public function delete(){
	global $wpdb;
	if($wpdb->query( $wpdb->prepare("DELETE FROM ".$this->table." WHERE id = %d", $this->id))){
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	return true;
	}
	return false;
}

//check address in db. return id if exists, false on failure
public function exists($address){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT id FROM ".$this->table." WHERE fullAddress = %s", $address);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		return $venue['id'];
	}else{return false;}
}

//venue in use by events. return array of event ids if in use, false if not.
public function inUse(){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT id, name FROM ".EOMEVENTS." WHERE venue_id = %d", $this->id);
	$events=$wpdb->get_results($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($events){return $events;}else{return false;}
}

//validation script
protected function _validate($data, $isReq, $min, $max, $type){
	$data=stripslashes(trim($data));
	if($data==''){if($isReq==true){return false;}else{return '';}}
	if( (strlen($data) > $max) or (strlen($data) < $min) ){return false;}
	if($type=='text'){$data=strip_tags($data);}
	return $data;
}

//return field select of approved venues selected with $id
public function fieldVenue($id=NULL){
	$venues=$this->getAll(array('order'=>'name'));
    $retSelect='<select name="venueId">';
	if (!$id){$retSelect.='<option value="" >Select Venue...</option>';}
	foreach ($venues as $key => $value) {
    	if ($id == $value['id']) {
		$retSelect.='<option value="'.$value['id'].'" selected="selected">'.stripslashes($value['name']).'</option>';
        }else{$retSelect.='<option value="'.$value['id'].'">'.$value['name'].'</option>';}
    }
	$retSelect.='</select>';
	return $retSelect;
}

}//END User
?>